==> order-center-domain-2.0.9-CLOUD-TEST-20220406.123138-53-sources.jar: com/tydic/dyc/oc/model/shiporder/qrybo/UocShipOrderQryBo.java <==
package com.tydic.dyc.oc.model.shiporder.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderQryBo
 * 说明:发货单
 * 时间:2022-02-21 19:12
 * 作者:罗有
 **/
@EqualsAndHashCode(callSuper = true)
@Data
public class UocShipOrderQryBo extends BasePageReqBo {
	private static final long serialVersionUID =  4479085140079952036L;

	@DocField(value = "发货单id")
	private Long shipOrderId;


	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "发货单编码")
	private String shipOrderNo;

	@DocField(value = "外部发货单编码")
	private String shipOrderNoExt;

	@DocField(value = "发货单名称")
	private String shipOrderName;

	@DocField(value = "发货单类型")
	private Integer shipOrderType;

	@DocField(value = "订单状态")
	private String shipOrderState;

	@DocField(value = "供应商编码")
	private String supNo;

	@DocField(value = "供应商账户")
	private String supAccount;

	@DocField(value = "物流公司id")
	private String shipCompanyId;

	@DocField(value = "物流公司名称")
	private String shipCompanyName;

	@DocField(value = "发货时间")
	private Date shipTime;

	@DocField(value = "发货时间 开始")
	private Date shipTimeStart;

	@DocField(value = "发货时间 结束")
	private Date shipTimeEnd;

	@DocField(value = "发货联系人姓名")
	private String shipName;

	@DocField(value = "发货联系人电话")
	private String shipPhone;

	@DocField(value = "发货工号")
	private String shipOperId;

	@DocField(value = "预计到货时间")
	private Date estimateArrivalTime;

	@DocField(value = "预计到货时间 开始")
	private Date estimateArrivalTimeStart;

	@DocField(value = "预计到货时间 结束")
	private Date estimateArrivalTimeEnd;

	@DocField(value = "到货时间")
	private Date arriveTime;

	@DocField(value = "到货时间 开始")
	private Date arriveTimeStart;

	@DocField(value = "到货时间 结束")
	private Date arriveTimeEnd;

	@DocField(value = "验收时间-该发货单全部被验收")
	private Date inspTime;

	@DocField(value = "验收时间-该发货单全部被验收 开始")
	private Date inspTimeStart;

	@DocField(value = "验收时间-该发货单全部被验收 结束")
	private Date inspTimeEnd;

	@DocField(value = "验收人名称")
	private String inspOperName;

	@DocField(value = "验收人工号")
	private String inspOperId;

	@DocField(value = "验收人电话")
	private String inspOperPhone;

	@DocField(value = "是否包含附件")
	private Integer isEnclosure;

	@DocField(value = "发货备注")
	private String shipRemark;

	@DocField(value = "到货备注")
	private String arriveRemark;

	@DocField(value = "收/拒收 货人")
	private String receiverUser;

	@DocField(value = "收/拒收 货备注")
	private String receiverRemark;

	@DocField(value = "收/拒收 联系人")
	private String receiverContact;

	@DocField(value = "收/拒收 时间")
	private Date receiverTime;

	@DocField(value = "收/拒收 时间 开始")
	private Date receiverTimeStart;

	@DocField(value = "收/拒收 时间 结束")
	private Date receiverTimeEnd;

	@DocField(value = "是否可以异常变更：1：不允许；其他情况都可以")
	private Integer isAbnormal;

	@DocField(value = "流转状态")
	private String procState;

	@DocField(value = "竣工标志             1 竣工             0 在途")
	private Integer finishFlag;

	@DocField(value = "租户ID")
	private String tenantId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "撤单时间")
	private Date cancelTime;

	@DocField(value = "撤单时间 开始")
	private Date cancelTimeStart;

	@DocField(value = "撤单时间 结束")
	private Date cancelTimeEnd;

	@DocField(value = "撤单工号")
	private String cancelOperId;

	@DocField(value = "撤单原因")
	private String cancelReason;

	@DocField(value = "撤单标志:1 已撤单             0 未撤单")
	private Integer cancelFlag;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "竣工时间")
	private Date finishTime;

	@DocField(value = "竣工时间 开始")
	private Date finishTimeStart;

	@DocField(value = "竣工时间 结束")
	private Date finishTimeEnd;

	@DocField(value = "逾期时间")
	private Date expTime;

	@DocField(value = "逾期时间 开始")
	private Date expTimeStart;

	@DocField(value = "逾期时间 结束")
	private Date expTimeEnd;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "发货单idList")
	private List<Long> shipOrderIdList;

}

==> order-center-domain-3.1.0-CLOUD-TEST-20230323.040333-46-sources.jar: com/tydic/dyc/oc/model/shiporder/qrybo/UocShipOrderQryBo.java <==
package com.tydic.dyc.oc.model.shiporder.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderQryBo
 * 说明:发货单
 * 时间:2022-02-21 19:12
 * 作者:罗有
 **/
@EqualsAndHashCode(callSuper = true)
@Data
public class UocShipOrderQryBo extends BasePageReqBo {
	private static final long serialVersionUID =  4479085140079952036L;

	@DocField(value = "发货单id")
	private Long shipOrderId;


	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "发货单编码")
	private String shipOrderNo;

	@DocField(value = "外部发货单编码")
	private String shipOrderNoExt;

	@DocField(value = "发货单名称")
	private String shipOrderName;

	@DocField(value = "发货单类型")
	private Integer shipOrderType;

	@DocField(value = "订单状态")
	private String shipOrderState;

	@DocField(value = "供应商编码")
	private String supNo;

	@DocField(value = "供应商账户")
	private String supAccount;

	@DocField(value = "物流公司id")
	private String shipCompanyId;

	@DocField(value = "物流公司名称")
	private String shipCompanyName;

	@DocField(value = "发货时间")
	private Date shipTime;

	@DocField(value = "发货时间 开始")
	private Date shipTimeStart;

	@DocField(value = "发货时间 结束")
	private Date shipTimeEnd;

	@DocField(value = "发货联系人姓名")
	private String shipName;

	@DocField(value = "发货联系人电话")
	private String shipPhone;

	@DocField(value = "发货工号")
	private String shipOperId;

	@DocField(value = "预计到货时间")
	private Date estimateArrivalTime;

	@DocField(value = "预计到货时间 开始")
	private Date estimateArrivalTimeStart;

	@DocField(value = "预计到货时间 结束")
	private Date estimateArrivalTimeEnd;

	@DocField(value = "到货时间")
	private Date arriveTime;

	@DocField(value = "到货时间 开始")
	private Date arriveTimeStart;

	@DocField(value = "到货时间 结束")
	private Date arriveTimeEnd;

	@DocField(value = "验收时间-该发货单全部被验收")
	private Date inspTime;

	@DocField(value = "验收时间-该发货单全部被验收 开始")
	private Date inspTimeStart;

	@DocField(value = "验收时间-该发货单全部被验收 结束")
	private Date inspTimeEnd;

	@DocField(value = "验收人名称")
	private String inspOperName;

	@DocField(value = "验收人工号")
	private String inspOperId;

	@DocField(value = "验收人电话")
	private String inspOperPhone;

	@DocField(value = "是否包含附件")
	private Integer isEnclosure;

	@DocField(value = "发货备注")
	private String shipRemark;

	@DocField(value = "到货备注")
	private String arriveRemark;

	@DocField(value = "收/拒收 货人")
	private String receiverUser;

	@DocField(value = "收/拒收 货备注")
	private String receiverRemark;

	@DocField(value = "收/拒收 联系人")
	private String receiverContact;

	@DocField(value = "收/拒收 时间")
	private Date receiverTime;

	@DocField(value = "收/拒收 时间 开始")
	private Date receiverTimeStart;

	@DocField(value = "收/拒收 时间 结束")
	private Date receiverTimeEnd;

	@DocField(value = "是否可以异常变更：1：不允许；其他情况都可以")
	private Integer isAbnormal;

	@DocField(value = "流转状态")
	private String procState;

	@DocField(value = "竣工标志             1 竣工             0 在途")
	private Integer finishFlag;

	@DocField(value = "租户ID")
	private String tenantId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "撤单时间")
	private Date cancelTime;

	@DocField(value = "撤单时间 开始")
	private Date cancelTimeStart;

	@DocField(value = "撤单时间 结束")
	private Date cancelTimeEnd;

	@DocField(value = "撤单工号")
	private String cancelOperId;

	@DocField(value = "撤单原因")
	private String cancelReason;

	@DocField(value = "撤单标志:1 已撤单             0 未撤单")
	private Integer cancelFlag;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "竣工时间")
	private Date finishTime;

	@DocField(value = "竣工时间 开始")
	private Date finishTimeStart;

	@DocField(value = "竣工时间 结束")
	private Date finishTimeEnd;

	@DocField(value = "逾期时间")
	private Date expTime;

	@DocField(value = "逾期时间 开始")
	private Date expTimeStart;

	@DocField(value = "逾期时间 结束")
	private Date expTimeEnd;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "发货单idList")
	private List<Long> shipOrderIdList;
	
	private List<UocShipOrderItemQryBo> shipOrderItemBoList;
    
    @DocField(value = "是否京东长直，1是，0否，默认0")
    private Integer jdCz;

}
